@@ -1,7 +1,7 @@
 import dataclasses
 import enum
 import typing
-from inspect import iscoroutine
+from inspect import isasyncgen, iscoroutine
 from typing import Any, Awaitable, Callable, Dict, List, Optional, Tuple, Type, Union
 
 from graphql import GraphQLResolveInfo
@@ -24,9 +24,9 @@ _RESOLVER_TYPE = Union[StrawberryResolver, Callable]
 class StrawberryField(dataclasses.Field):
     def __init__(
         self,
-        python_name: Optional[str],
-        graphql_name: Optional[str],
-        type_: Optional[Union[Type, StrawberryUnion]],
+        python_name: Optional[str] = None,
+        graphql_name: Optional[str] = None,
+        type_: Optional[Union[Type, StrawberryUnion]] = None,
         origin: Optional[Union[Type, Callable]] = None,
         child: Optional["StrawberryField"] = None,
         is_subscription: bool = False,
@@ -38,7 +38,7 @@ class StrawberryField(dataclasses.Field):
         description: Optional[str] = None,
         base_resolver: Optional[StrawberryResolver] = None,
         permission_classes: List[Type[BasePermission]] = (),  # type: ignore
-        default_value: Any = UNSET,
+        default: object = UNSET,
         default_factory: Union[Callable, object] = UNSET,
         deprecation_reason: Optional[str] = None,
     ):
@@ -48,9 +48,9 @@ class StrawberryField(dataclasses.Field):
         is_basic_field = not base_resolver
 
         super().__init__(  # type: ignore
-            default=(default_value if default_value != UNSET else dataclasses.MISSING),
+            default=(default if default is not UNSET else dataclasses.MISSING),
             default_factory=(
-                default_factory if default_factory != UNSET else dataclasses.MISSING
+                default_factory if default_factory is not UNSET else dataclasses.MISSING
             ),
             init=is_basic_field,
             repr=is_basic_field,
@@ -73,7 +73,11 @@ class StrawberryField(dataclasses.Field):
         if base_resolver is not None:
             self.base_resolver = base_resolver
 
-        self.default_value = default_value
+        # Note: StrawberryField.default is the same as
+        # StrawberryField.default_value except that `.default` uses
+        # `dataclasses.MISSING` to represent an "undefined" value and
+        # `.default_value` uses `UNSET`
+        self.default_value = default
 
         self.child = child
         self.is_child_optional = is_child_optional
@@ -264,6 +268,14 @@ class StrawberryField(dataclasses.Field):
 
             result = self.get_result(_source, info=strawberry_info, kwargs=kwargs)
 
+            if isasyncgen(result):
+
+                async def yield_results(results):
+                    async for value in results:
+                        yield _convert_enums_to_values(self, value)
+
+                return yield_results(result)
+
             if iscoroutine(result):  # pragma: no cover
 
                 async def await_result(result):
@@ -329,7 +341,7 @@ def field(
         permission_classes=permission_classes or [],
         federation=federation or FederationFieldParams(),
         deprecation_reason=deprecation_reason,
-        default_value=default,
+        default=default,
         default_factory=default_factory,
     )
 
